#
# spec file for package audaspace
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Shared_library_packaging_policy
# NOTE: sover follows version.
%define sover 1_7
%define soversion 1.7

%if %{pkg_vcmp pipewire-devel >= 1.4.0}
%bcond_without pipewire
%else
%bcond_with    pipewire
%endif

Name:           audaspace
Version:        1.7.0
Release:        1.1
Summary:        A High-Level Audio Library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://audaspace.github.io/
Source0:        https://github.com/audaspace/audaspace/archive/refs/tags/v%{version}.tar.gz#/audaspace-%{version}.tar.gz
BuildRequires:  cmake > 3
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  graphviz-gd
BuildRequires:  pkg-config
BuildRequires:  python3-base
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libavcodec) >= 61.3.100
BuildRequires:  pkgconfig(libavformat) >= 61.1.100
BuildRequires:  pkgconfig(libavutil) >= 59.8.100
BuildRequires:  pkgconfig(libpipewire-0.3)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sndfile)

%description
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library. This package contains demo binaries.

%package        plugin-ffmpeg
Summary:        FFmpeg plugin for %{name}
Group:          System/Libraries
Provides:       audaspace-fileplugin
Supplements:    libaudaspace%{sover}

%description    plugin-ffmpeg
Audaspace (pronounced "outer space") is a high-level audio library.
This package contains the FFmpeg plugin

%package        plugin-jack
Summary:        JACK plugin for %{name}
Group:          System/Libraries
Provides:       audaspace-deviceplugin

%description    plugin-jack
Audaspace (pronounced "outer space") is a high-level audio library.
This package contains the JACK plugin

%package        plugin-openal
Summary:        OpenAL plugin for %{name}
Group:          System/Libraries
Provides:       audaspace-deviceplugin

%description    plugin-openal
Audaspace (pronounced "outer space") is a high-level audio library.
This package contains the OpenAL plugin

%package        plugin-pulse
Summary:        Pulseaudio plugin for %{name}
Group:          System/Libraries
Provides:       audaspace-deviceplugin
Supplements:    (libaudaspace%{sover} and (pulseaudio or pulseaudio-pipewire))

%description    plugin-pulse
Audaspace (pronounced "outer space") is a high-level audio library.
This package contains the Pulseaudio plugin

%if %{with pipewire}
%package        plugin-pipewire
Summary:        Pipewire plugin for %{name}
Group:          System/Libraries
Provides:       audaspace-deviceplugin
Supplements:    (libaudaspace%{sover} and pipewire)

%description    plugin-pipewire
Audaspace (pronounced "outer space") is a high-level audio library.
This package contains the Pipewire plugin
%endif

%package        plugin-sdl2
Summary:        SDL2 plugin for %{name}
Group:          System/Libraries
Provides:       audaspace-deviceplugin

%description    plugin-sdl2
Audaspace (pronounced "outer space") is a high-level audio library.
This package contains the SDL2 plugin

%package        plugin-sndfile
Summary:        Sndfile plugin for %{name}
Group:          System/Libraries
Provides:       audaspace-fileplugin

%description    plugin-sndfile
Audaspace (pronounced "outer space") is a high-level audio library.
This package contains the Sndfile plugin

%package -n libaudaspace%{sover}
Summary:        A high-level audio library
Group:          System/Libraries
Recommends:     audaspace-deviceplugin
Recommends:     audaspace-fileplugin

%description -n libaudaspace%{sover}
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library.

%package -n libaudaspace-c%{sover}
Summary:        C bindings for %{name}
Group:          System/Libraries

%description -n libaudaspace-c%{sover}
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library.

%package -n libaudaspace-py%{sover}
Summary:        Python Bindings for %{name}
Group:          System/Libraries

%description -n libaudaspace-py%{sover}
Audaspace (pronounced "outer space") is a high-level audio library written
in C++ with language bindings for Python for example. It started out as the
audio engine of the 3D modelling application Blender and is now released as
a standalone library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libaudaspace%{sover} = %{version}
Requires:       libaudaspace-c%{sover} = %{version}
Requires:       libaudaspace-py%{sover} = %{version}
Recommends:     %{name}-doc = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML
Recommends:     %{name}-devel = %{version}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation for
developing applications that use %{name}.

%prep
%setup -n audaspace-%{version} -q
%autopatch -p1

%build
%cmake \
    -DWITH_VERSIONED_PLUGINS:BOOL=FALSE \
    -DWITH_FFMPEG:BOOL=TRUE \
    -DDEFAULT_PLUGIN_PATH:PATH=%{_libdir}/%{name}-%{soversion} \
    -DWITH_PYTHON_MODULE:BOOL=off \
    -DDOCUMENTATION_INSTALL_PATH:PATH=%{_docdir}/%{name}
%cmake_build

%install
%cmake_install

%fdupes %{buildroot}%{_docdir}/%{name}

%post -n libaudaspace%{sover} -p /sbin/ldconfig

%postun -n libaudaspace%{sover} -p /sbin/ldconfig

%post -n libaudaspace-c%{sover} -p /sbin/ldconfig

%postun -n libaudaspace-c%{sover} -p /sbin/ldconfig

%post -n libaudaspace-py%{sover} -p /sbin/ldconfig

%postun -n libaudaspace-py%{sover} -p /sbin/ldconfig

%files
%license LICENSE
%{_bindir}/*

%files plugin-ffmpeg
%{_libdir}/%{name}-%{soversion}/libaudffmpeg.so

%files plugin-jack
%{_libdir}/%{name}-%{soversion}/libaudjack.so

%files plugin-openal
%{_libdir}/%{name}-%{soversion}/libaudopenal.so

%files plugin-pulse
%{_libdir}/%{name}-%{soversion}/libaudpulseaudio.so

%if %{with pipewire}
%files plugin-pipewire
%{_libdir}/%{name}-%{soversion}/libaudpipewire.so
%endif

%files plugin-sdl2
%{_libdir}/%{name}-%{soversion}/libaudsdl.so

%files plugin-sndfile
%{_libdir}/%{name}-%{soversion}/libaudlibsndfile.so

%files -n libaudaspace%{sover}
%dir %{_libdir}/%{name}-%{soversion}
%{_libdir}/libaudaspace.so.%{soversion}

%files -n libaudaspace-c%{sover}
%{_libdir}/libaudaspace-c.so.%{soversion}

%files -n libaudaspace-py%{sover}
%{_libdir}/libaudaspace-py.so.%{soversion}

%files doc
%doc AUTHORS CHANGES README.md
%dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/*

%files devel
%{_libdir}/pkgconfig/*
%{_includedir}/*
%{_libdir}/*.so

%changelog
* Wed Jul  2 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to release 1.7.0
  - Rewrite of the Synchronizer API.
  - Unified backends with a mixing thread (Jack, Pulse, Pipewire,
    CoreAudio)
  - Various fixes for CoreAudio.
* Wed Mar 19 2025 Marcus Rueckert <mrueckert@suse.de>
- instead of disabling pipewire support based on the OS version
  tie that decision to the pipewire version
* Mon Mar 17 2025 Marcus Rueckert <mrueckert@suse.de>
- disable pipewire support on leap 15.x until we find out why the
  build does not find the development files.
* Mon Mar  3 2025 Marcus Rueckert <mrueckert@suse.de>
- fix soversion
* Sun Mar  2 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to release 1.6.0
  - Pipewire support (thanks Sebastian Parborg!)
  - AAC container (ADTS stream).
  - Update to C++17.
  - Improvements for PulseAudio backend.
  - Many (bug) fixes.
- drop git.patch
* Sat Mar  1 2025 Marcus Rueckert <mrueckert@suse.de>
- add git.patch to get the needed symbols (like AUD_CONTAINER_AAC)
  needed in blender 4.4.
  https://github.com/audaspace/audaspace/issues/30
- enable pipewire plugin
  new audaspace-plugin-pipewire plugin
* Wed Jul 17 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to release 1.5.0
  Audaspace 1.5.0 is a release with not many changes but big enough
  to warrant a new release after a year since the last one.
  - Performance improvements and two more quality presets for the
    JOS resampler.
  - Bugfixes for PulseAudio.
  - CoreAudio device is only opened on demand.
  - FFMPEG 7 support and dropped support for FFMPEG older than 6.
  - Various minor fixes and improvements.
- drop audaspace-animated-sequence.patch
* Sun Nov 26 2023 draskmont@protonmail.com
- Added upstream patch audaspace-animated-sequence.patch:
  * Aditional functions required by Blender 4.0.
  * Bugfix for reading an animated property with a negative
    time value
* Sat Feb  4 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to release 1.4.0
  * Support for OS specific/native audio devices/backends has been
    added, that is PulseAudio (Linux), WASAPI (Windows) and
    CoreAudio (MacOS).
  * New sound effects have been added, namely Modulator and
    Equalizer. Thanks to Marcos Perez for contributing the
    Equalizer.
  * File stream info: if an audio file contains multiple streams
    you can choose which one to process instead of taking the first
    one (this feature is only supported by ffmpeg, not libsndfile).
  * API Change: double instead of float for time values for more
    precise timing control.
  * There have been lots of bugfixes, which are basically the
    majority of all changes.
  * And some other minor improvements were implemented as well.
- Drop upstream patches:
  * audaspace-gcc7.patch
  * audaspace-plugin-build-options.patch
  * audaspace-support-ffmpeg4.patch
  * 034645c883a51dfc8897dccce15aa8ee4a9d5c8c.patch
- Add pkgconfig(pulse) to allow audio via pulseaudio/pipewire
- Use pkgconfig(jack), let distro select jack implementation
- Split plugins packages to avoid pulling in excessive
  dependencies, and recommend at least one device plugin from
  the library.
* Wed Jul 13 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 034645c883a51dfc8897dccce15aa8ee4a9d5c8c.patch: Support
  ffmpeg v5, patch from upstream git.
* Mon Nov 18 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
* Thu Jul 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build on x86_64 and aarch64, do not overwrite -fPIC with -fPIE
- Spec cleanup, remove defattr, use license macro
- Use graphviz-gd instead of graphviz-gnome
* Tue Feb 12 2019 bjorn.lie@gmail.com
- Add audaspace-support-ffmpeg4.patch: Fix build with ffmpeg 4.
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Sat Apr 21 2018 jengelh@inai.de
- Explicitly request ffmpeg 3.x for building
* Mon Oct 23 2017 davejplater@gmail.com
- Added upstream patch audaspace-plugin-build-options.patch as
  final fix for boo#1057965 and audaspace issue#10.
- Build example executables as position independent executables.
* Wed Oct 18 2017 davejplater@gmail.com
- Delete plugin symlinks and remove version suffixes to further fix
  boo#1057965 and audaspace issue#10
* Fri Sep 22 2017 davejplater@gmail.com
- Moved lib*.so plugin symlinks from the devel package to the
  pluginsn package as a temporary work around for boo#1057965
  reported upstream https://github.com/audaspace/audaspace/issues/10
* Tue Mar 28 2017 davejplater@gmail.com
- Fix gcc7 build by requiring graphviz-gnome and creating
  audaspace-gcc7.patch to add missing #include <functional>
* Sat Feb 11 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
  Update descriptions.
* Fri Feb 10 2017 davejplater@gmail.com
- Update to release 1.3.0
- Removed patch audaspace-findffmpeg.patch Fixed upstream
- Upstream changes:
  * Audaspace 1.3.0 is a bug fixing release without changes to the
    API, but two small new features:
    linear interpolation for volume changes in the software mixer
    dynamic Loading for JACK
  * Bug fixes:
    renamed Jack to JACK
    C API was not working
    filter python API parameter check
    finding ffmpeg with pkgconfig
* Sun Jul  3 2016 mpluskal@suse.com
- Fix building with recent cmake (macros), which default to -fPIE
* Mon Jun 27 2016 davejplater@gmail.com
- Fixed build with upstream patch audaspace-findffmpeg.patch
* Tue Apr 19 2016 davejplater@gmail.com
- Update to release 1.2
- Upstream changes :
  New features:
    sound list
    random sounds
    dynamic music playing
    playback manager
    convolution/reverbation
    multi-threading
    binaural audio
    API changes:
    changing default sample rate from 44.1 to 48 kHz
    Bug fixes:
    several standard library fixes.
    Bindings API:
    mixdown C API refactored
    CMake/Building:
    assuring numpy is installed
* Tue Feb 16 2016 davejplater@gmail.com
- Added ffmpeg to build for newer that 13.2
* Thu Oct 22 2015 normand@linux.vnet.ibm.com
- for ppc64le architecture disable __ALTIVEC__ to avoid build error
  to avoid contention between SDL vector and gcc defines
* Sat Oct 17 2015 davejplater@gmail.com
- Update to version 1.1
- Remove audaspace-datetime.patch and audaspace-pkgcnflib.patch
  issues fixed upstream.
- Upstream changes:
  * Bug fixes:
    pkgconfig uses cmake configured library directory
    FFMPEG file writing crashed, also corrected pts for encoding
    silenced Doxygen warnings about undefined defines
  * C++ API:
    ResampleReader uses specs instead of sample rate
  * Bindings API:
    writing sounds to files
    reading sound data, specs and length
    resampling sounds
  * CMake/Building:
    first steps towards building for Mac
    windows builds copy dlls automatically
  * Python module:
    using distutils instead of setuptools
    added numpy as dependency
  * Documentation:
    added windows building and plugin documentation
    disabled html timestamps in doxygen
    updated sphinx template
    build binding documentation without installing the python module
* Fri Aug  7 2015 davejplater@gmail.com
- Created package audaspace which was previously a part of blender
  but is an external standalone library as from blender 2.80.
- Created audaspace-datetime.patch to remove time stamps from the
  documentation.
- Created audaspace-pkgcnflib.patch to give the correct _libdir for
  x86_64 builds, it was hardcoded to /lib.
- Features:
  * input/output devices
  input from microphones, line in, etc.
  output devices including 3D audio support
  * file reading/writing
  * filters like low-/highpass and effects like delay, reverse
  or fading
  * generators for simple waveforms like silence, sine and triangle
  * respecification - is used for changing stream parameters which are
  channel count - channel remapping
  sample format - the library internally uses 32 bit floats
  sample rate - resampling
  * simple (superposition, joining and ping-pong aka forward-reverse)
  and more complex (non-linear audio editing) sequencing of sounds
